# Generated by Django 3.1.5 on 2021-03-15 13:54

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ingress', '0008_auto_20210315_1454'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='FailedIngressQueue',
            new_name='FailedMessage',
        ),
        migrations.RenameModel(
            old_name='IngressQueue',
            new_name='Message',
        ),
    ]
