# Generated by Django 3.1.5 on 2021-03-15 13:54

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ingress', '0007_auto_20210315_1451'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='Endpoint',
            new_name='Collection',
        ),
        migrations.RenameField(
            model_name='collection',
            old_name='url_key',
            new_name='name',
        ),
        migrations.RenameField(
            model_name='failedingressqueue',
            old_name='parse_fail_info',
            new_name='consume_fail_info',
        ),
        migrations.RenameField(
            model_name='failedingressqueue',
            old_name='parse_failed_at',
            new_name='consume_failed_at',
        ),
        migrations.RenameField(
            model_name='failedingressqueue',
            old_name='parse_started',
            new_name='consume_started_at',
        ),
        migrations.RenameField(
            model_name='failedingressqueue',
            old_name='parse_succeeded',
            new_name='consume_succeeded_at',
        ),
        migrations.RenameField(
            model_name='ingressqueue',
            old_name='parse_started',
            new_name='consume_started_at',
        ),
        migrations.RenameField(
            model_name='ingressqueue',
            old_name='parse_succeeded',
            new_name='consume_succeeded_at',
        ),
    ]
