# Generated by Django 2.2.16 on 2020-11-05 14:25

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("ingress", "0002_auto_20201104_1740"),
    ]

    operations = [
        migrations.CreateModel(
            name="FailedIngressQueue",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                ("raw_data", models.TextField()),
                ("parse_started", models.DateTimeField(null=True)),
                ("parse_succeeded", models.DateTimeField(null=True)),
                ("parse_failed", models.DateTimeField(null=True)),
                ("parse_fail_info", models.TextField(null=True)),
                (
                    "endpoint",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="ingress.Endpoint",
                    ),
                ),
            ],
        ),
    ]
