# Generated by Django 3.0.11 on 2020-11-09 15:49

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("ingress", "0003_failedingressqueue"),
    ]

    operations = [
        migrations.AddField(
            model_name="endpoint",
            name="is_active",
            field=models.BooleanField(default=True),
        ),
        migrations.AlterField(
            model_name="failedingressqueue",
            name="endpoint",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.PROTECT, to="ingress.Endpoint"
            ),
        ),
    ]
