# Generated by Django 2.2.16 on 2020-11-04 16:40

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("ingress", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="Endpoint",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("url_key", models.CharField(max_length=255, unique=True)),
            ],
        ),
        migrations.AlterField(
            model_name="ingressqueue",
            name="endpoint",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE, to="ingress.Endpoint"
            ),
        ),
    ]
