# Generated by Django 3.0.11 on 2020-11-20 12:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("ingress", "0005_auto_20201109_2132"),
    ]

    operations = [
        migrations.AddField(
            model_name="endpoint",
            name="parser_enabled",
            field=models.BooleanField(default=False),
        ),
    ]
