# Generated by Django 3.1.5 on 2021-03-15 13:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ingress', '0006_endpoint_parser_enabled'),
    ]

    operations = [
        migrations.RenameField(
            model_name='endpoint',
            old_name='parser_enabled',
            new_name='consumer_enabled',
        ),
        migrations.RenameField(
            model_name='endpoint',
            old_name='is_active',
            new_name='ingress_enabled',
        ),
        migrations.RenameField(
            model_name='failedingressqueue',
            old_name='endpoint',
            new_name='collection',
        ),
        migrations.RenameField(
            model_name='failedingressqueue',
            old_name='parse_failed',
            new_name='parse_failed_at',
        ),
        migrations.RenameField(
            model_name='ingressqueue',
            old_name='endpoint',
            new_name='collection',
        ),
        migrations.RemoveField(
            model_name='ingressqueue',
            name='parse_fail_info',
        ),
        migrations.RemoveField(
            model_name='ingressqueue',
            name='parse_failed',
        ),
        migrations.AlterField(
            model_name='endpoint',
            name='url_key',
            field=models.SlugField(help_text="The end of the url and also the key with which it can be retrieved from the queue. For example, in the url /ingress/example, the string 'example' is the name of the collection.", max_length=255, unique=True),
        ),
        migrations.AlterField(
            model_name='failedingressqueue',
            name='parse_fail_info',
            field=models.TextField(help_text='To store stack traces or other info about the fail', null=True),
        ),
        migrations.AlterField(
            model_name='failedingressqueue',
            name='parse_started',
            field=models.DateTimeField(db_index=True, null=True),
        ),
        migrations.AlterField(
            model_name='failedingressqueue',
            name='parse_succeeded',
            field=models.DateTimeField(db_index=True, null=True),
        ),
        migrations.AlterField(
            model_name='failedingressqueue',
            name='raw_data',
            field=models.TextField(help_text='To store raw received data to be consumed by a separate consumer'),
        ),
        migrations.AlterField(
            model_name='ingressqueue',
            name='parse_started',
            field=models.DateTimeField(db_index=True, null=True),
        ),
        migrations.AlterField(
            model_name='ingressqueue',
            name='parse_succeeded',
            field=models.DateTimeField(db_index=True, null=True),
        ),
        migrations.AlterField(
            model_name='ingressqueue',
            name='raw_data',
            field=models.TextField(help_text='To store raw received data to be consumed by a separate consumer'),
        ),
    ]
